summaryrefslogtreecommitdiff
path: root/filter/source/config/cache/basecontainer.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'filter/source/config/cache/basecontainer.cxx')
-rw-r--r--filter/source/config/cache/basecontainer.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/filter/source/config/cache/basecontainer.cxx b/filter/source/config/cache/basecontainer.cxx
index de888aaf0aab..1d33f5f0e9e4 100644
--- a/filter/source/config/cache/basecontainer.cxx
+++ b/filter/source/config/cache/basecontainer.cxx
@@ -90,7 +90,7 @@ void BaseContainer::impl_loadOnDemand()
::osl::ResettableMutexGuard aLock(m_aLock);
// A generic container needs all items of a set of our cache!
// Of course it can block for a while, till the cache is realy filled.
// Note: dont load all sets supported by the cache here!
FilterCache::EFillState eRequiredState = FilterCache::E_CONTAINS_NOTHING;
@@ -423,7 +423,7 @@ sal_Bool SAL_CALL BaseContainer::hasElements()
css::uno::Reference< css::container::XEnumeration > SAL_CALL BaseContainer::createSubSetEnumerationByQuery(const OUString& /* sQuery */ )
throw (css::uno::RuntimeException)
{
- OSL_FAIL("not pure virtual ... but not realy implemented .-)");
+ OSL_FAIL("not pure virtual ... but not really implemented .-)");
::comphelper::OEnumerationByName* pEnum = new ::comphelper::OEnumerationByName(this, css::uno::Sequence< OUString >());
return css::uno::Reference< css::container::XEnumeration >(static_cast< css::container::XEnumeration* >(pEnum), css::uno::UNO_QUERY);
@@ -90,7 +90,7 @@ void BaseContainer::impl_loadOnDemand()
::osl::ResettableMutexGuard aLock(m_aLock);
// A generic container needs all items of a set of our cache!
- // Of course it can block for a while, till the cache is realy filled.
+ // Of course it can block for a while, till the cache is really filled.
// Note: dont load all sets supported by the cache here!
FilterCache::EFillState eRequiredState = FilterCache::E_CONTAINS_NOTHING;